# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# This file is part of GNU Health.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.exceptions import UserError
from trytond.model.exceptions import ValidationError


class EndDateBeforeStart(ValidationError):
    pass


class ORNotAvailable(ValidationError):
    pass


class OperatingRoomAndDateRequired(UserError):
    pass


class EndReservationBeforeStart(UserError):
    pass


class SurgeryDone(UserError):
    pass
